# Syntax Highlighting: A Plugin for Pelican

[![Build Status](https://github.com/f-koehler/pelican-syntax-highlighting/actions/workflows/main.yml/badge.svg)](https://github.com/f-koehler/pelican-syntax-highlighting/actions/workflows/main.yml)
[![PyPI Version](https://img.shields.io/pypi/v/pelican-syntax-highlighting)](https://pypi.org/project/pelican-syntax-highlighting/)
![License](https://img.shields.io/pypi/l/pelican-syntax-highlighting?color=blue)
[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/f-koehler/pelican-syntax-highlighting/main.svg)](https://results.pre-commit.ci/latest/github/f-koehler/pelican-syntax-highlighting/main)

Highlight syntax using Prism.js, Highlight.js or Pygments

## Installation

This plugin can be installed via:

    python -m pip install pelican-syntax-highlighting

## Usage

<<Add plugin details here>>

## Contributing

Contributions are welcome and much appreciated. Every little bit helps. You can contribute by improving the documentation, adding missing features, and fixing bugs. You can also help out by reviewing and commenting on [existing issues][].

To start contributing to this plugin, review the [Contributing to Pelican][] documentation, beginning with the **Contributing Code** section.

[existing issues]: https://github.com/f-koehler/pelican-syntax-highlighting/issues
[contributing to pelican]: https://docs.getpelican.com/en/latest/contribute.html

## License

This project is licensed under the AGPL-3.0 license.
